@@ -73,7 +73,7 @@ class Base(object):
                 allure.dynamic.story(param.get('story'))
             request.node.name = param.get('title')
         logger.info('开始运行用例:{}'.format(param.get('title')))
-        if conf.settings.get('is_hook_logger', True) is False:
+        if conf.settings.get('is_hook_logger', True) is True:
             logger.info(param)
         yield param
 
@@ -113,15 +113,15 @@ class Base(object):
             if name.startswith("request"):
                 client = getattr(conf.settings, name)
                 for j in client.kwargs.get('setup_hook', []):
-                    if conf.settings.get('is_hook_logger', True) is False:
+                    if conf.settings.get('is_hook_logger', True) is True:
                         self.logger.info('{}注册setup_hook：{}'.format(name, j))
                     client.register_setup_hook(self.get_func(j))
                 for j in client.kwargs.get('teardown_hook', []):
-                    if conf.settings.get('is_hook_logger', True) is False:
+                    if conf.settings.get('is_hook_logger', True) is True:
                         self.logger.info('{}注册teardown_hook：{}'.format(name, j))
                     client.register_teardown_hook(self.get_func(j))
                 for j in client.kwargs.get('except_hook', []):
-                    if conf.settings.get('is_hook_logger', True) is False:
+                    if conf.settings.get('is_hook_logger', True) is True:
                         self.logger.info('{}注册except_hook：{}'.format(name, j))
                     client.register_except_hook(self.get_func(j))
         yield
