@@ -7,6 +7,7 @@ import time
 import websocket
 from ..common import logger
 from . import api
+from threading import Thread
 
 
 class WebSocket(websocket.WebSocket):
@@ -40,7 +41,7 @@ class WebSocket(websocket.WebSocket):
             raise e
         else:
             total_time = int((time.time() - start_time) * 1000)
-            logger.debug("websocket建联:url:{},header:{}，用时:{}毫秒".format(host, header, total_time))
+            logger.info("websocket建联:url:{},header:{}，用时:{}毫秒".format(host, header, total_time))
             self.request_success("连接", response_time=total_time)
 
     def reconnect(self):
@@ -56,7 +57,7 @@ class WebSocket(websocket.WebSocket):
             data = json.loads(zlib.decompress(data, 16 + zlib.MAX_WBITS))
         else:
             data = json.loads(data)
-        logger.debug('---recv---:type:{},{}'.format(_type, data))
+        logger.info('---recv---:type:{},{}'.format(_type, data))
         if 'ping' in data:
             self.request_success("ping接收")
         elif 'pong' in data:
@@ -82,7 +83,7 @@ class WebSocket(websocket.WebSocket):
         """
         msg = json.dumps(msg)
         start_time = time.time()
-        logger.debug('---send---:{}'.format(msg))
+        logger.info('---send---:{}'.format(msg))
         super().send(msg)
         self.request_success("发送消息", response_time=time.time() - start_time)
 
@@ -93,7 +94,7 @@ class WebSocket(websocket.WebSocket):
         """
         msg = {"ping": int(time.time() * 1000)}
         msg = json.dumps(msg)
-        logger.debug('---ping---:{}'.format(msg))
+        logger.info('---ping---:{}'.format(msg))
         start_time = time.time()
         super().send(msg)
         self.request_success("心跳ping日志", response_time=time.time()-start_time)
@@ -107,7 +108,7 @@ class WebSocket(websocket.WebSocket):
         msg = json.dumps(msg)
         start_time = time.time()
         super().send(msg)
-        logger.debug('发送pong请求:{}'.format(msg))
+        logger.info('发送pong请求:{}'.format(msg))
         self.request_success("心跳pong日志", response_time=time.time()-start_time)
 
     def get_status(self):
@@ -121,14 +122,12 @@ class WebSocket(websocket.WebSocket):
         super().handshake_response.status = status
 
 
-
-
-
 class webSocket(api.Api):
 
     def __init__(self, kwargs):
         super().__init__()
         self.kwargs = kwargs
+        self.logger_level = kwargs.get('logger_level', 'debug')
 
     def get_client(self, api_id, *topics, header=None, **kwargs) -> websocket.WebSocketApp:
         api_data = self.get_api(api_id)
@@ -148,37 +147,40 @@ class webSocket(api.Api):
         ws.title = api_data['title']
         return ws
 
-    def run_forever(self, ws:websocket.WebSocketApp, *args, **kwargs):
+    def run_forever(self, ws: websocket.WebSocketApp, *args, **kwargs):
         # ws.run_forever(*args, **kwargs)
-        import _thread
-        _thread.start_new_thread(ws.run_forever, args=args, kwargs=kwargs)
+        t = Thread(target=ws.run_forever, args=args, kwargs=kwargs)
+        t.setDaemon(True)
+        t.start()
         return ws
 
-    def on_data(self, ws:websocket.WebSocketApp, message, data_type, flag):
-        logger.debug("{}内容：{}，类型：{}，flage：{}".format(ws.title, message, data_type, flag))
+    def on_data(self, ws: websocket.WebSocketApp, message, data_type, flag):
+        logger.info("{}内容：{}，类型：{}，flage：{}".format(ws.title, message, data_type, flag))
 
-    def on_close(self, ws:websocket.WebSocketApp, close_status_code, close_msg):
-        logger.debug("{}关闭连接,状态码:{}, 关闭消息:{}.....".format(ws.title, close_status_code, close_msg))
+    def on_close(self, ws: websocket.WebSocketApp, close_status_code, close_msg):
+        logger.info("{}关闭连接,状态码:{}, 关闭消息:{}.....".format(ws.title, close_status_code, close_msg))
 
-    def on_error(self, ws:websocket.WebSocketApp, exception):
+    def on_error(self, ws: websocket.WebSocketApp, exception):
         if getattr(exception, 'format_exc', None) is not None:
-            logger.debug("异常():{}".format(ws.title, exception.format_exc()))
+            logger.info("异常():{}".format(ws.title, exception.format_exc()))
         else:
-            logger.exception("异常({})".format(ws.title))
+            logger.error(f"异常({ws.title}):{traceback.format_exc()}")
 
-    def on_open(self, ws:websocket.WebSocketApp):
-        logger.debug(f"websocket(name:{ws.title}, host:{ws.url})连接成功.....")
+    def on_open(self, ws: websocket.WebSocketApp):
+        logger.info(f"websocket(name:{ws.title}, host:{ws.url})连接成功.....")
         ws.open_start_time = time.time()
         for topic in ws.topics:
-            logger.debug(f'注册topic:{topic}')
+            logger.info(f'注册topic:{topic}')
             ws.send(json.dumps(topic))
 
-    def on_pong(self, ws:websocket.WebSocketApp, message):
-        logger.debug("{}收到pong消息:{}".format(ws.title, message))
+    def on_pong(self, ws: websocket.WebSocketApp, message):
+        if self.logger_level == 'debug':
+            logger.debug("{}收到pong消息:{}".format(ws.title, message))
 
-    def on_ping(self, ws:websocket.WebSocketApp, message):
+    def on_ping(self, ws: websocket.WebSocketApp, message):
         ws.send(json.dumps({"pong": int(time.time() * 1000)}), websocket.ABNF.OPCODE_PONG)
-        logger.debug("{}收到ping消息:{}".format(ws.title, message))
+        if self.logger_level == 'debug':
+            logger.debug("{}收到ping消息:{}".format(ws.title, message))
 
-    def on_message(self, ws:websocket.WebSocketApp, message):
-        logger.debug("{}收到消息:{}".format(ws.title, message))
+    def on_message(self, ws: websocket.WebSocketApp, message):
+        logger.info("{}收到消息:{}".format(ws.title, message))
