@@ -54,16 +54,18 @@ def run_case(data: list, _uuid: str, env: str):
     if not os.path.exists(folder):
         os.makedirs(folder)
     _path = os.path.join(folder, 'case.json')
-    if conf.settings.get('is_hook_logger', True) is False:
+    if conf.settings.get('is_hook_logger', True) is True:
         logger.info('执行数据：{}, 数据地址:{}'.format(_data, _path))
     with open(_path, 'w+')as f:
         f.write(json.dumps(_data, sort_keys=True, indent=4, separators=(',', ':')))
 
     _path = os.path.join(constant.TMP_REPORTS_DIR, _uuid)
-    command = ['-s', '--capture=no', '-vvv', '--alluredir', _path, '--clean-alluredir',
-               '--cache-clear', '-W', 'ignore:Module already imported:pytest.PytestWarning', '--{}'.format(json_name),
-               _uuid]
-    if conf.settings.get('is_hook_logger', True) is False:
+    command = ['-s', '--capture=no']
+    if conf.settings.get('is_hook_logger', True) is True:
+        command += ['-vvv']
+    command += ['--alluredir', _path, '--clean-alluredir', '--cache-clear', '-W',
+                'ignore:Module already imported:pytest.PytestWarning', '--{}'.format(json_name), _uuid]
+    if conf.settings.get('is_hook_logger', True) is True:
         logger.info('执行命令:{}'.format(command))
     pytest.main(command)
 
@@ -152,11 +154,11 @@ class Run(object):
         logger.info('开始 {} {}(环境:{})的 {} 用例'.format('运行' if conf.settings.run.is_debug is False else '调试'
                                                          , conf.settings.run.env, conf.settings.run.env_name,
                                                          conf.settings.run.test_case))
-        if conf.settings.get('is_hook_logger', True) is False:
+        if conf.settings.get('is_hook_logger', True) is True:
             logger.info('开始收集测试用例。。。。。')
         group, surplus_data = self.collect_use_cases()
         self.run_data = [j for i in group for j in i] + [j for i in surplus_data for j in i]
-        if conf.settings.get('is_hook_logger', True) is False:
+        if conf.settings.get('is_hook_logger', True) is True:
             logger.info(self.run_data)
         if len(self.run_data) > 0:
             self.run_case(self.run_data)
@@ -304,12 +306,9 @@ class Run(object):
                                 self.all_data_by_channel_id[env][case['id']] = []
 
                             tag_case_list = self.calculation_tag_case(case)
-                            print(tag_case_list)
 
                             self.all_data_by_channel_id[env][case['id']] += tag_case_list
                             self.all_data += tag_case_list
-                            # self.all_data_by_channel_id[env][case['id']].append(copy.deepcopy(case))
-                            # self.all_data.append(copy.deepcopy(case))
         self.replace_base_data()
 
     def calculation_tag_case(self, case):
